summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorRuss Cox <rsc@golang.org>2014-09-06 21:16:13 -0400
committerRuss Cox <rsc@golang.org>2014-09-06 21:16:13 -0400
commit1d2be0d3f233300d7953493b0c2f2ca315e1c7da (patch)
tree848037ed15809aa22c814e741c0e808bd2f483c0 /test
parent8191545e191c83c85e07f8ab1a718e0e315436a1 (diff)
downloadgo-1d2be0d3f233300d7953493b0c2f2ca315e1c7da.tar.gz
runtime: increase stack split limit again
Increase NOSPLIT reservation from 192 to 384 bytes. The problem is that the non-Unix systems (Solaris and Windows) just can't make system calls in a small amount of space, and then worse they do things that are complex enough to warrant calling runtime.throw on failure. We don't have time to rewrite the code to use less stack. I'm not happy about this, but it's still a small amount. The good news is that we're doing this to get to only using copying stacks for stack growth. Once that is true, we can drop the default stack size from 8k to 4k, which should more than make up for the bytes we're losing here. LGTM=r R=iant, r, bradfitz, aram.h CC=golang-codereviews https://codereview.appspot.com/140350043
Diffstat (limited to 'test')
-rw-r--r--test/nosplit.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/nosplit.go b/test/nosplit.go
index 3854f2420..c9d008acd 100644
--- a/test/nosplit.go
+++ b/test/nosplit.go
@@ -256,11 +256,11 @@ TestCases:
name := m[1]
size, _ := strconv.Atoi(m[2])
// The limit was originally 128 but is now 192.
// Instead of rewriting the test cases above, adjust
// the first stack frame to use up the extra 32 bytes.
if i == 0 {
- size += 192 - 128
+ size += 384 - 128
}
if goarch == "amd64" && size%8 == 4 {
@@ -256,11 +256,11 @@ TestCases:
name := m[1]
size, _ := strconv.Atoi(m[2])
- // The limit was originally 128 but is now 192.
+ // The limit was originally 128 but is now 384.
// Instead of rewriting the test cases above, adjust
// the first stack frame to use up the extra 32 bytes.